(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    103457,       2732]
NotebookOptionsPosition[     95911,       2626]
NotebookOutlinePosition[     96303,       2642]
CellTagsIndexPosition[     96260,       2639]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
A simple theoretical model for lags and asymmetries of surface temperature\
\>", "Title",
 CellChangeTimes->{{3.8291326329485483`*^9, 
  3.82913263472368*^9}},ExpressionUUID->"f3a83daf-1766-4437-b239-\
f2b40d90fcfa"],

Cell[CellGroupData[{

Cell["Generation of the dataset", "Section",
 CellChangeTimes->{{3.828531800469637*^9, 
  3.8285318078375177`*^9}},ExpressionUUID->"d5a07e46-faaa-4a41-b47d-\
5e6dd09e7319"],

Cell[TextData[{
 "It is well known that Meteorology and Climatology are different subjects, \
and manuals roughly define Climate as ",
 StyleBox["the average over a period of 30-50 years of meteorological \
phenomena",
  FontSlant->"Italic"],
 ". Let us put to work this definition."
}], "Text",
 CellChangeTimes->{{3.828594945280641*^9, 3.8285950356884108`*^9}, {
  3.828766166362973*^9, 
  3.828766166652973*^9}},ExpressionUUID->"555795d1-e7c8-4b73-85dd-\
d720dfa53314"],

Cell["\<\
In what follows, once chosen a particular  WMO station (that typically is \
labelled with WMO followed by a five-digits number but that it can also be \
labelled as a ICAO code if it is situated in an airport) we produce \
timeseries in which time is time is expressed in days in UTC, starting from \
January 1st, 00:00 and ending in December 31st, 24:00 and the values are the \
temperature or the humidity measured by the given station.\
\>", "Text",
 CellChangeTimes->{{3.8285231946423597`*^9, 3.828523261067094*^9}, {
  3.828523320608899*^9, 3.8285234029252033`*^9}, {3.828531824383767*^9, 
  3.828531838059457*^9}, {3.8285950420177526`*^9, 3.828595131727243*^9}, {
  3.828595197107637*^9, 3.828595253445331*^9}, {3.828766183451138*^9, 
  3.8287662917619047`*^9}},ExpressionUUID->"bddd78d3-2ddd-48e6-81be-\
2739a5150eff"],

Cell[TextData[{
 "The time step of the dataseries depends on the choice of a variable called ",
 StyleBox["bin",
  FontColor->RGBColor[0, 0, 1]],
 " is chosen automatically based on the number of available data by giving to \
a variable called ",
 StyleBox["bin",
  FontFamily->"Arial",
  FontWeight->"Regular",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" the average value of data per day.",
  FontFamily->"Arial",
  FontWeight->"Regular",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.8285952548192577`*^9, 3.8285952870939503`*^9}, {
  3.828595360887795*^9, 3.828595440299972*^9}, {3.828766304868248*^9, 
  3.828766309092853*^9}, {3.8287678878660192`*^9, 3.8287679431714973`*^9}, {
  3.8287694722076807`*^9, 
  3.828769480858314*^9}},ExpressionUUID->"218fe883-0878-4eaa-b185-\
b7687c7485b0"],

Cell["\<\
Les us set the working directory as the directory in which the notebook \
resides\
\>", "Text",
 CellChangeTimes->{{3.828597688909772*^9, 3.8285977122397013`*^9}, {
  3.828766318047271*^9, 
  3.828766318319141*^9}},ExpressionUUID->"6b299363-7657-4498-981a-\
76658d6a9114"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.828597714070671*^9, 3.828597724280501*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"d61f5abb-0f2c-4ea5-a852-f2b698cc294a"],

Cell[TextData[{
 "Once given a code (",
 StyleBox["code",
  FontColor->RGBColor[0, 0, 1]],
 ") a beginning year (",
 StyleBox["begin",
  FontColor->RGBColor[0, 0, 1]],
 ") a final year (",
 StyleBox["end",
  FontColor->RGBColor[0, 0, 1]],
 ") and a number of measures per day (",
 StyleBox["bin",
  FontColor->RGBColor[0, 0, 1]],
 "), the following function saves in the home directory two DAT files \
labelled ",
 StyleBox["tmp_code.dat",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["hmd_code.dat",
  FontColor->RGBColor[0, 0, 1]],
 " (code is variable) relative to the average temperature and humidity. The \
functions also prints, for every year, the number of data per day that are \
being retrieved (this is strictly related to the choice of bin)."
}], "Text",
 CellChangeTimes->{{3.828597807861659*^9, 3.828597856140307*^9}, {
  3.828766326431044*^9, 3.828766328671503*^9}, {3.828766399760941*^9, 
  3.8287665216016827`*^9}, {3.828766565548563*^9, 3.828766656826207*^9}, {
  3.828767143761963*^9, 3.8287671842622004`*^9}, {3.828767252228059*^9, 
  3.828767367232202*^9}, {3.828788466390275*^9, 3.8287884907063446`*^9}, {
  3.828793611702939*^9, 3.828793612867433*^9}, {3.828794696622937*^9, 
  3.828794751244029*^9}},ExpressionUUID->"f4950ab2-21ec-49da-a226-\
10e1118fff20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"code_", ",", "begin_", ",", "end_", ",", "bin_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"year", "=", "begin"}], ";", 
     RowBox[{"InitialYear", "=", "begin"}], ";", 
     RowBox[{"FinalYear", "=", "end"}], ";", 
     RowBox[{"listtmp", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"listhmd", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"year", "\[LessEqual]", "  ", "end"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"beginningTime", "=", 
         RowBox[{"AbsoluteTime", "[", 
          RowBox[{"{", 
           RowBox[{
           "year", ",", "01", ",", "01", ",", "00", ",", "00", ",", "00"}], 
           "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"endingTime", "=", 
         RowBox[{"AbsoluteTime", "[", 
          RowBox[{"{", 
           RowBox[{
           "year", ",", "12", ",", "31", ",", "23", ",", "59", ",", "59"}], 
           "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"tmp", "=", 
         RowBox[{"WeatherData", "[", 
          RowBox[{"code", ",", "\"\<Temperature\>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"DateString", "[", "beginningTime", "]"}], ",", 
             RowBox[{"DateString", "[", "endingTime", "]"}]}], "}"}]}], 
          "]"}]}], ";", 
        RowBox[{"Print", "[", 
         RowBox[{"{", 
          RowBox[{"year", ",", 
           RowBox[{"Floor", "[", 
            FractionBox[
             RowBox[{"Length", "[", 
              RowBox[{"tmp", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "2", ",", "1", ",", "1"}], "]"}], "]"}], 
              "]"}], "365"], "]"}]}], "}"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"hmd", "=", 
         RowBox[{"WeatherData", "[", 
          RowBox[{"code", ",", "\"\<Humidity\>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"DateString", "[", "beginningTime", "]"}], ",", 
             RowBox[{"DateString", "[", "endingTime", "]"}]}], "}"}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"listtmp", "=", 
         RowBox[{"listtmp", "~", "Join", "~", 
          RowBox[{"Select", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"N", "[", " ", 
                FractionBox[
                 RowBox[{
                  RowBox[{"tmp", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", ",", "2", ",", "1", ",", "1"}], "]"}], "]"}],
                   "-", "beginningTime"}], 
                 RowBox[{"60", "*", "60", "*", "24"}]], "]"}], ",", 
               RowBox[{"Map", "[", 
                RowBox[{"QuantityMagnitude", ",", 
                 RowBox[{"tmp", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ",", "1", ",", "1"}], "]"}], "]"}]}], "]"}]}],
               "}"}], "]"}], ",", 
            RowBox[{
             RowBox[{"NumberQ", "[", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "&"}]}], "]"}]}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"listhmd", "=", 
         RowBox[{"listhmd", "~", "Join", "~", 
          RowBox[{"Select", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"N", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"hmd", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", ",", "2", ",", "1", ",", "1"}], "]"}], "]"}],
                   "-", "beginningTime"}], 
                 RowBox[{"60", "*", "60", "*", "24"}]], "]"}], ",", 
               RowBox[{"hmd", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "1", ",", "1"}], "]"}], "]"}]}], "}"}], 
             "]"}], ",", 
            RowBox[{
             RowBox[{"NumberQ", "[", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "&"}]}], "]"}]}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"year", "=", 
         RowBox[{"year", "+", "1"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<tmp_\>\"", ",", "code", ",", "\"\<.dat\>\""}], "]"}], 
       ",", 
       RowBox[{"N", "[", 
        RowBox[{"Map", "[", 
         RowBox[{"Mean", ",", 
          RowBox[{"SplitBy", "[", 
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   FractionBox["1", "bin"]}], "]"}], ",", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
              RowBox[{"Sort", "[", "listtmp", "]"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "&"}]}], "]"}]}], "]"}], 
        "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<hmd_\>\"", ",", "code", ",", "\"\<.dat\>\""}], "]"}], 
       ",", 
       RowBox[{"N", "[", 
        RowBox[{"Map", "[", 
         RowBox[{"Mean", ",", 
          RowBox[{"SplitBy", "[", 
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   FractionBox["1", "bin"]}], "]"}], ",", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
              RowBox[{"Sort", "[", "listhmd", "]"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "&"}]}], "]"}]}], "]"}], 
        "]"}]}], "]"}], ";"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.828682717061591*^9, 3.828682846799191*^9}, {
  3.828682919446796*^9, 3.828682961587538*^9}, {3.8286830079184628`*^9, 
  3.828683030429474*^9}, {3.828766365738277*^9, 3.828766370220397*^9}, {
  3.828767414360243*^9, 3.8287675317219276`*^9}, {3.828767750117633*^9, 
  3.828767813161028*^9}, {3.8287689026351833`*^9, 3.828768926177781*^9}, {
  3.828769205327241*^9, 3.828769207225503*^9}, {3.828769312849053*^9, 
  3.8287693309337187`*^9}, {3.8287885059653907`*^9, 3.828788506575753*^9}, {
  3.8287886087265196`*^9, 3.8287886266257706`*^9}},
 CellLabel->
  "In[148]:=",ExpressionUUID->"69b92b07-b9d2-496a-b15c-89b48245b077"],

Cell["\<\
In our investigation we did analyze in details 6 places on Earth:
Haway, Hilo airport, PHTO or WMO91285
Lybia, Kufra airport, HLKF or WMO62271
Italy,  Catania airport, LICC or WMO16460
USA, Lincoln airport, KLNK or WMO72551
Antartica, Vostok station, WMO89606 (non in the database I found)
Australia, Sydney airport, YSSY or WMO94767
We write the lines that will produce the dataset of our interest\
\>", "Text",
 CellChangeTimes->{{3.828766661023315*^9, 3.828766702322505*^9}, {
   3.8287667958152514`*^9, 3.828766819732258*^9}, {3.8287669213668623`*^9, 
   3.828767001073937*^9}, 3.82877000213741*^9, {3.8287712463049307`*^9, 
   3.828771351422103*^9}, 3.828788659483413*^9, {3.828789561390072*^9, 
   3.828789575021619*^9}, {3.8287896144213457`*^9, 3.828789622612441*^9}, {
   3.828794034881433*^9, 3.828794039106724*^9}, {3.828794078230896*^9, 
   3.828794084353751*^9}, {3.8287943094511747`*^9, 3.828794309639533*^9}, {
   3.828794475276184*^9, 3.828794476111615*^9}, {3.829118191090262*^9, 
   3.829118218475136*^9}},ExpressionUUID->"74595441-440f-4812-a02e-\
d93d2bb0ceea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"\"\<PHTO\>\"", ",", "1973", ",", "2020", ",", "24"}], "]"}], " ", 
  RowBox[{"(*", "hilo", "*)"}]}]], "Input",
 CellChangeTimes->{
  3.828769832171917*^9, {3.828770414437389*^9, 
   3.828770415540875*^9}},ExpressionUUID->"b4c52e71-ef85-4236-b98d-\
ff299b7a5aa3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"\"\<HLKF\>\"", ",", "1973", ",", "2020", ",", "8"}], "]"}], " ", 
  RowBox[{"(*", "kufra", "*)"}]}]], "Input",
 CellChangeTimes->{
  3.828769840096018*^9, 3.828769955857107*^9, {3.828770078976041*^9, 
   3.828770080990749*^9}, {3.828770170219139*^9, 3.828770170714224*^9}, {
   3.828770302482439*^9, 3.8287703029167337`*^9}, 
   3.8287713564050837`*^9},ExpressionUUID->"0daae329-afe0-4c8d-9329-\
6d9fa2cd2b87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"\"\<LICC\>\"", ",", "1973", ",", "2020", ",", "24"}], "]"}], " ", 
  RowBox[{"(*", "catania", "*)"}]}]], "Input",
 CellChangeTimes->{{3.8287675110178833`*^9, 3.82876754833643*^9}, {
  3.828769342556748*^9, 3.828769343112163*^9}, {3.828769801292466*^9, 
  3.828769838230253*^9}, {3.828770403631318*^9, 3.828770408337023*^9}, {
  3.829118191281816*^9, 3.8291182053746243`*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"3b16e1de-fd87-4c6e-92cb-e82b71985d1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"\"\<KLNK\>\"", ",", "1973", ",", "2020", ",", "24"}], "]"}], " ", 
  RowBox[{"(*", "lincoln", "*)"}]}]], "Input",
 CellChangeTimes->{{3.8287698447814627`*^9, 3.828769849856488*^9}, {
   3.8287699362353497`*^9, 3.828769937940761*^9}, 3.828770397344808*^9, {
   3.828771360474168*^9, 
   3.828771366321107*^9}},ExpressionUUID->"bbf33c36-c223-4529-99a5-\
93318ff9912d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"\"\<WMO89606\>\"", ",", "1973", ",", "2020", ",", "4"}], "]"}], 
  " ", 
  RowBox[{"(*", "vostok", "*)"}]}]], "Input",
 CellChangeTimes->{{3.828771370153322*^9, 3.8287713751597843`*^9}, {
  3.8287896648956513`*^9, 3.828789670960648*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"7c6c111b-29d3-4c12-b6c4-7c95999b6fed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"datasettmphmd", "[", 
   RowBox[{"\"\<YSSY\>\"", ",", "1973", ",", "2020", ",", "24"}], "]"}], " ", 
  RowBox[{"(*", "sydney", "*)"}]}]], "Input",
 CellChangeTimes->{{3.828789675041724*^9, 3.8287896821896076`*^9}, {
  3.828794090041418*^9, 
  3.828794094385415*^9}},ExpressionUUID->"d14c1600-3055-4798-8a91-\
b59efab230c7"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation", "Section",
 CellChangeTimes->{{3.828531800469637*^9, 3.8285318078375177`*^9}, {
  3.8287947912889147`*^9, 
  3.828794794336699*^9}},ExpressionUUID->"6e87f9a4-ee61-4928-bbc1-\
8ec5533d17a0"],

Cell["\<\
The system has a certain number of fixed parameters. We define them in \
groups. The first thing to do is to choose the code of the weather station \
(the same code we used in the previous chapter).\
\>", "Text",
 CellChangeTimes->{{3.828794798788397*^9, 3.828794827162992*^9}, {
  3.828795078789831*^9, 3.828795092596107*^9}, {3.828795232193701*^9, 
  3.8287952325938*^9}, {3.828795384296146*^9, 3.828795414158807*^9}, {
  3.8291180751947117`*^9, 
  3.829118129665824*^9}},ExpressionUUID->"8179347b-0e42-416b-9f0c-\
aa2b7742c907"],

Cell[BoxData[
 RowBox[{
  RowBox[{"code", "=", "\"\<LICC\>\""}], " ", 
  RowBox[{"(*", 
   RowBox[{"to", " ", "be", " ", "filled"}], "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.828795403754438*^9, 3.8287954716115217`*^9}, {
  3.8291181316994658`*^9, 3.829118132349671*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"6cbc63f3-18b4-429c-adf4-20eb1107f326"],

Cell[TextData[{
 "Then we fix the parameters. Invariable for the Earth are the ",
 StyleBox["astronomical parameters",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.8287952339210787`*^9, 3.828795248046927*^9}, {
  3.828795572323409*^9, 3.8287955804139633`*^9}, {3.829116156084543*^9, 
  3.829116182170849*^9}},ExpressionUUID->"9e0960fa-3ebd-4186-897f-\
1fbd7adc2613"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]B", "=", 
    RowBox[{"5.670373", " ", "*", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "8"}]]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Stefan", "-", 
    RowBox[{"Boltzmann", " ", "Constant"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TSun", "=", "5778"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Superficial", " ", "temperature", " ", "of", " ", "the", " ", "Sun"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RS", "=", "695700000"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Sun", " ", "radius"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dESun", "=", "149600000000"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Earth", "-", 
    RowBox[{"Sun", " ", "distance"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]", "=", "0.0167"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Earth", " ", "orbit", " ", 
    RowBox[{"eccentricity", "."}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]", " ", "=", " ", 
    RowBox[{
     FractionBox["13", "365"], "*", "2", "\[Pi]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Angle", " ", "between", " ", "perihelion", "  ", "and", " ", "winter", 
    " ", "solstice"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]", "=", 
   RowBox[{"Re", "[", " ", 
    RowBox[{"23.27", " ", "Degree"}], "]"}]}], ";", " ", 
  RowBox[{"(*", "obliquity", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Day", "=", 
   RowBox[{"3600", "*", "24"}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"average", " ", "solar", " ", "day", " ", "in", " ", "seconds"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Year", "=", 
   RowBox[{"Day", "*", "365.242199"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalOmega]", " ", "=", 
   RowBox[{"2", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "Day"], "+", " ", 
      FractionBox["1", "Year"]}], ")"}]}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"2", 
    RowBox[{"\[Pi]", "/", "sidereal"}], " ", "day", " ", "expressed", " ", 
    "in", " ", "seconds"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"RE", "=", "6378136"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"equatorial", " ", "Earth", " ", "radius"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"RP", "=", "6356751.302"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"polar", " ", "Earth", " ", "radius"}], "*)"}], 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.828794873395446*^9, 3.828794888861437*^9}, {
  3.828795095270548*^9, 3.828795149285673*^9}, {3.82879519103047*^9, 
  3.8287952683708878`*^9}, {3.82911644937842*^9, 3.8291164532943*^9}, {
  3.8291168182303743`*^9, 3.8291168489000587`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"029ed9f9-848b-45e6-a6f6-dce24c618af1"],

Cell[TextData[{
 "Variable but dependent on the location are ",
 StyleBox["latitude and longitude",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.828795300695488*^9, 3.8287953072219*^9}, {
  3.828795566670742*^9, 3.828795569255342*^9}, {3.8291161852573223`*^9, 
  3.829116194624448*^9}, {3.829116387097705*^9, 
  3.829116388046674*^9}},ExpressionUUID->"e8341638-958a-49c5-93b2-\
91872d06599d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"lat", ",", "long"}], "}"}], "=", 
   RowBox[{"WeatherData", "[", 
    RowBox[{"code", ",", "\"\<Coordinates\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyPhi]", "=", 
   RowBox[{"Re", "[", 
    RowBox[{"lat", " ", "Degree"}], "]"}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Latitude", " ", "of", " ", "the", " ", "system"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"\[Psi]", "=", 
   RowBox[{"Re", "[", 
    RowBox[{"long", " ", "Degree"}], "]"}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Longitude", " ", "of", " ", "the", " ", "system"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{
  3.828795226252369*^9, {3.8287953205378523`*^9, 3.828795376356481*^9}, 
   3.8291162001040382`*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"3c8f919f-bae9-4b28-acd2-7981f3414917"],

Cell[TextData[{
 "Variable but also dependent on the location are the ",
 StyleBox["geothermal parameters",
  FontWeight->"Bold"],
 ". They have very little influence on simulations of Earth."
}], "Text",
 CellChangeTimes->{{3.8287952701619577`*^9, 3.828795283212659*^9}, {
  3.828795558509652*^9, 3.828795585040225*^9}, {3.829116212188384*^9, 
  3.829116251688015*^9}, {3.8291163049486933`*^9, 
  3.829116342328115*^9}},ExpressionUUID->"4360af3d-13b0-4cc8-b325-\
bff20ef0528d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"RW", "=", 
    RowBox[{
     RowBox[{"RE", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"RP", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "-", "15000"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Oceanic", " ", "Moho", " ", "discontinuity", " ", "depth"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RG", "=", 
    RowBox[{
     RowBox[{"RE", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"RP", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "-", "35000"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Continental", " ", "Moho", " ", "discontinuity", " ", "depth"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T1G", "=", "700"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Supericial", " ", "temperature", " ", "at", " ", "the", " ", "Moho", " ", 
    "discontinuity", " ", "under", " ", "the", " ", "continental", " ", 
    "crust"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T1W", "=", "700"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Supericial", " ", "temperature", " ", "at", " ", "the", " ", "Moho", " ", 
    "discontinuity", " ", "under", " ", "the", " ", "oceanic", " ", "crust"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T2", "=", "300"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "average", " ", "superficial", " ", "temperature", " ", "on", " ", 
    "Earth"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kW", "=", "30"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Thermal", " ", "conductivity", " ", "in", " ", "the", " ", "oceanic", " ",
     "crust"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kG", "=", "30"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Thermal", " ", "conductivity", " ", "in", " ", "the", " ", "continental", 
    " ", "crust"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"qW", "=", 
    RowBox[{"N", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"T1W", "-", "T2"}], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"4", "\[Pi]", " ", "kW"}]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "RW"], "-", 
          FractionBox["1", 
           RowBox[{
            RowBox[{"RE", " ", 
             RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
            RowBox[{"RP", " ", 
             RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]]}], ")"}]}]], 
      FractionBox["1", 
       RowBox[{"4", "\[Pi]", " ", 
        SuperscriptBox["RW", "2"]}]]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Thermal", " ", "power", " ", "of", " ", "energy", " ", "from", " ", "the",
     " ", "mantle", " ", "for", " ", "a", " ", "unit", " ", "of", " ", 
    "surface", " ", "on", " ", "the", " ", "oceanic", " ", "crust"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"qG", "=", 
    RowBox[{"N", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"T1G", "-", "T2"}], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"4", "\[Pi]", " ", "kG"}]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "RG"], "-", 
          FractionBox["1", 
           RowBox[{
            RowBox[{"RE", " ", 
             RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
            RowBox[{"RP", " ", 
             RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]]}], ")"}]}]], 
      FractionBox["1", 
       RowBox[{"4", "\[Pi]", " ", 
        SuperscriptBox["RG", "2"]}]]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Thermal", " ", "power", " ", "of", " ", "energy", " ", "from", " ", "the",
     " ", "mantle", " ", "for", " ", "a", " ", "unit", " ", "of", " ", 
    "surface", " ", "on", " ", "the", " ", "continental", " ", "crust"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.828795286073421*^9, 3.828795286223456*^9}, {
  3.828795504490306*^9, 3.828795531373884*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"582f03cb-8117-431e-927b-9d1e7a64c1f4"],

Cell[TextData[{
 "Parameters that depend very much on the climatic type of the region under \
investigation are the ",
 StyleBox["climatic parameters",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.828795534543154*^9, 3.828795535125012*^9}, {
  3.828795620126566*^9, 3.8287956471054487`*^9}, {3.8287957002741613`*^9, 
  3.828795706046414*^9}, {3.8291162875269403`*^9, 3.829116294079733*^9}, {
  3.829116346091601*^9, 
  3.829116370469968*^9}},ExpressionUUID->"7326a8c9-c062-46ce-b9ee-\
f41c79ea109a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"p", "=", "0.6"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"fraction", " ", "of", " ", "ground"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", 
   RowBox[{"1", "-", "p"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"fraction", " ", "of", " ", "water"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"\[Mu]", "=", 
   RowBox[{"2.8", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "evaporation", " ", "rate", " ", "from", " ", "soil", " ", "and", " ", 
    "water"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[Nu]", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"rainfall", " ", "rate"}], "*)"}], " "}]}], "Input",
 CellChangeTimes->{
  3.828795616887043*^9, {3.8287956581116858`*^9, 3.828795659363637*^9}, {
   3.828795697840493*^9, 3.828795739944975*^9}, {3.829116411505826*^9, 
   3.829116433822465*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"17231944-f58a-404a-ac45-e40284c55f26"],

Cell[TextData[{
 "Also somehow variable are the ",
 StyleBox["thermal capacities",
  FontWeight->"Bold"],
 ". They depend on the depth of the layer and the type of material for the \
soil and the presence of iced water."
}], "Text",
 CellChangeTimes->{{3.828795661767681*^9, 3.8287956734249077`*^9}, {
  3.8291164011818*^9, 3.829116409032279*^9}, {3.829116474485454*^9, 
  3.829116526257123*^9}},ExpressionUUID->"004c3704-eede-4bbe-a823-\
a2a481a36847"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[ScriptL]0", "=", " ", "400"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"depth", " ", "of", " ", "atmosphere"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]0", "=", "1.225"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"density", " ", "of", " ", "air"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Cl", " ", "=", 
    RowBox[{"1", "*", 
     SuperscriptBox["10", "6"]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"heat", " ", "capacity", " ", "of", " ", "soil"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"C0d", " ", "=", " ", 
    RowBox[{"711.28", "*", "\[Rho]0", "*", "\[ScriptL]0"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"heat", " ", "capacity", " ", "dry", " ", "air"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"C0v", " ", "=", " ", 
    RowBox[{"2050.16", "*", "\[Rho]0", "*", "\[ScriptL]0"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"heat", " ", "capacity", " ", "water", " ", "vapor"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[ScriptL]w", "=", "40"}], " ", 
   RowBox[{"(*", 
    RowBox[{"depth", " ", "of", " ", "water"}], "*)"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cw", " ", "=", " ", 
   RowBox[{"4214.4", " ", "*", "1000", "*", "\[ScriptL]w"}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"heat", " ", "capacity", " ", "of", " ", "water"}], "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.828795678381393*^9, 3.8287956960970793`*^9}, {
   3.8287957432599688`*^9, 3.828795757471218*^9}, 3.8287960251511374`*^9, {
   3.828796089809778*^9, 3.828796094848528*^9}, {3.828796165884748*^9, 
   3.828796232106963*^9}, {3.829116462189666*^9, 3.829116471400104*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"47457cfb-deff-49dc-8a00-a652bdec992a"],

Cell[TextData[{
 "Invariable are the ",
 StyleBox["latent heats",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.8287960290760727`*^9, 3.828796032941959*^9}, {
  3.829116531744088*^9, 
  3.829116542030456*^9}},ExpressionUUID->"efe67ee0-4c12-41ab-a08b-\
c6ad5b7a56d7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", " ", "2260000"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Latent", " ", "heat", " ", "of", " ", "vaporization", " ", "and", " ", 
    "of", " ", "condensation", " ", 
    RowBox[{"(", 
     RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]", "=", " ", 
    RowBox[{"\[Lambda]", " ", "*", "\[Rho]0", "*", "\[ScriptL]0"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{
   "Latent", " ", "heat", " ", "of", " ", "vaporization", " ", "and", " ", 
    "of", " ", "condensation", " ", 
    RowBox[{"(", 
     RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.828796035925241*^9, 3.828796056516714*^9}, {
  3.828796241187456*^9, 3.828796256216901*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"0cf31df3-6278-433b-9632-4bc5f9035ae7"],

Cell[TextData[{
 "Also variable are the ",
 StyleBox["optical parameters",
  FontWeight->"Bold"],
 ". Reflectance and emissivity depend on the substance being irradiated"
}], "Text",
 CellChangeTimes->{{3.828795773341701*^9, 3.8287957800348*^9}, {
  3.829116551424178*^9, 
  3.829116611645247*^9}},ExpressionUUID->"eb85cb95-71b8-465f-93b4-\
df997b81e592"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]W", "=", "0.94"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"emissivity", " ", "water"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]W", "=", "0.85"}], ";", " ", 
   RowBox[{"(*", 
    RowBox[{"absorbance", " ", "water"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"\[Tau]W", "=", "0"}], ";", 
   RowBox[{"(*", 
    RowBox[{"transmittance", " ", "water", " ", 
     RowBox[{"(", 
      RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"rW", "=", 
    RowBox[{"1", "-", "\[Alpha]W", "-", "\[Tau]W"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"reflectance", " ", "water"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]G", "=", "0.94"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"emissivity", " ", "soil"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]G", "=", "0.8"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"absorbance", " ", "soil"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Tau]G", "=", "0"}], ";", " ", 
   RowBox[{"(*", 
    RowBox[{"trasmittance", " ", "soil", " ", 
     RowBox[{"(", "fixed", ")"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"rG", "=", 
    RowBox[{"1", "-", "\[Alpha]G", "-", "\[Tau]G"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"reflectance", " ", "soil"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]Au", "=", "0.45"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"emissivity", " ", "air", " ", "upwards", " ", 
    RowBox[{"(", 
     RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]Ad", "=", "0.8"}], ";", " ", 
   RowBox[{"(*", 
    RowBox[{"emissivity", " ", "air", " ", "downwards", " ", 
     RowBox[{"(", 
      RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"\[Tau]A", "=", "0.52"}], ";", " ", 
   RowBox[{"(*", 
    RowBox[{"trasmittance", " ", "air", " ", 
     RowBox[{"(", 
      RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"rA", "=", "0.23"}], ";", " ", 
   RowBox[{"(*", 
    RowBox[{"reflectance", " ", "air", " ", 
     RowBox[{"(", 
      RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"\[Alpha]A", "=", 
    RowBox[{"1", "-", "\[Tau]A", "-", "rA"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"absorbance", " ", "air", " ", 
    RowBox[{"(", 
     RowBox[{"do", " ", "not", " ", "touch"}], ")"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]AT", "=", "0.86"}], ";", 
  RowBox[{"(*", 
   RowBox[{"absorbance", " ", "infrared", " ", "air"}], "*)"}], 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.828795783544424*^9, 3.8287960001812487`*^9}, {
  3.8287962698521767`*^9, 3.828796280475182*^9}, {3.829116722290436*^9, 
  3.829116776675432*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"45af90a2-0202-4631-9d65-570b4b4f6e82"],

Cell[TextData[{
 "Finally, variable are the ",
 StyleBox["linear heat transfer coefficients",
  FontWeight->"Bold"],
 ". They model the way in which convection exchanges heat between the \
materials."
}], "Text",
 CellChangeTimes->{{3.828796105179812*^9, 3.8287961438123426`*^9}, {
  3.829116626654599*^9, 
  3.829116675642879*^9}},ExpressionUUID->"9f9ed3b5-d2d8-4acb-a4e5-\
5df7a8363000"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hAG", "=", "12"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Heat", " ", "transfer", " ", "coefficient", " ", "air"}], "-", 
    "ground"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hAW", "=", "28.5"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Heat", " ", "transfer", " ", "coefficient", " ", "air"}], "-", 
    "water"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.828796120537431*^9, 3.8287961372815933`*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"a97f1aeb-4cc2-4829-a242-4b0c2f7e6f2b"],

Cell[TextData[{
 "These two function are functions of time. Once the position of the Earth \
with respect to the Sun \[CurlyTheta][t] and the position of the region on \
Earth ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Psi]", "+", 
    RowBox[{"t", " ", "\[CapitalOmega]"}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"10", " ", "Day"}], "Year"], "*", "2", "\[Pi]"}]}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e59df95f-471f-42ed-8991-1900ad2a5300"],
 " are known, the function SolRad gives the intensity of solar radiation that \
hits a square meter of upper atmosphere."
}], "Text",
 CellChangeTimes->{{3.8291168718849077`*^9, 3.829116903363603*^9}, {
  3.829116955939219*^9, 
  3.829117101235387*^9}},ExpressionUUID->"87340c08-b044-433d-8a16-\
930b9f1bc4a8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"scalprod", "[", "t_", "]"}], ":=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"RE", " ", 
        RowBox[{"Cos", "[", "\[Gamma]", "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Delta]", "+", 
          RowBox[{"\[CurlyTheta]", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", 
          RowBox[{"t", " ", "\[CapitalOmega]"}], "+", 
          RowBox[{
           FractionBox[
            RowBox[{"10", " ", "Day"}], "Year"], "*", "2", "\[Pi]"}]}], 
         "]"}]}], 
       SqrtBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["RE", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["RP", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], "2"]}]}]]]}], "-", 
     FractionBox[
      RowBox[{"RP", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Delta]", "+", 
         RowBox[{"\[CurlyTheta]", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "\[Gamma]", "]"}], " ", 
       RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["RE", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["RP", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], "2"]}]}]]], "-", 
     FractionBox[
      RowBox[{"RE", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Delta]", "+", 
         RowBox[{"\[CurlyTheta]", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Psi]", "+", 
         RowBox[{"t", " ", "\[CapitalOmega]"}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{"10", " ", "Day"}], "Year"], "*", "2", "\[Pi]"}]}], 
        "]"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["RE", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["RP", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], "2"]}]}]]]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SolRad", "[", "t_", "]"}], ":=", 
   RowBox[{"Max", "[", 
    RowBox[{
     RowBox[{"\[Sigma]B", " ", 
      SuperscriptBox["TSun", "4"], " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["RS", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Epsilon]", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[CurlyTheta]", "[", "t", "]"}], "]"}]}]}], ")"}], 
         "2"]}], 
       RowBox[{
        SuperscriptBox["dESun", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Epsilon]", "2"]}], ")"}], "2"]}]], 
      RowBox[{"scalprod", "[", "t", "]"}]}], ",", "0"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8291168681814613`*^9, 3.829116869467594*^9}, {
  3.82911690993902*^9, 3.829116939660315*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"60aed318-a606-4326-bf45-18de0c0e65cf"],

Cell["\<\
The dynamical system goes to a periodic equilibrium solution. We have to give \
the right initial data to make sure that the solution is at thermal \
equilibrium. The following procedure is needed to define the initial data. \
The last recurrence gives directly the solution of our model. The \
interpolating functions are stored in the variable solution\
\>", "Text",
 CellChangeTimes->{{3.829117110967856*^9, 3.8291172274564047`*^9}, {
  3.8291174040894327`*^9, 
  3.8291174824613647`*^9}},ExpressionUUID->"225a226a-b0bd-403f-8d21-\
6c55d773c46e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TW0", "=", 
    RowBox[{"273.15", "+", "5"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "guess", " ", "for", " ", "initial", " ", "temperature", " ", "of", " ", 
    "water"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TA0", "=", 
    RowBox[{"273.15", "+", "4"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "guess", " ", "for", " ", "initial", " ", "temperature", " ", "of", " ", 
    "air"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TG0", "=", " ", 
    RowBox[{"273.15", "+", "5"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "guess", " ", "for", " ", "initial", " ", "temperature", " ", "of", " ", 
    "soil"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U0", "=", " ", "0.2"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "guess", " ", "for", " ", "initial", " ", "absolute", " ", "humidity"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CurlyTheta]0", " ", "=", " ", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "365"]}], "2", "\[Pi]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "initial", " ", "angle", " ", "between", " ", "perihelion", " ", "and", 
     " ", 
     RowBox[{"solstice", ".", " ", "The"}], " ", "initial", " ", "time", " ", 
     "is", " ", "on", " ", "January", " ", "1", "st"}], ",", " ", 
    RowBox[{
    "the", " ", "Earth", " ", "is", " ", "at", " ", "perihelion", " ", "on", 
     " ", "January", " ", "4", "th"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"system", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C0d", " ", "+", " ", 
         RowBox[{"C0v", " ", 
          RowBox[{"U", "[", "t", "]"}]}]}], ")"}], "   ", 
       RowBox[{
        RowBox[{"TA", "'"}], "[", "t", "]"}]}], "\[Equal]", " ", 
      RowBox[{
       RowBox[{"\[Alpha]A", "  ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"p", " ", "\[Tau]A", " ", "rG"}], " ", "+", " ", 
          RowBox[{"q", " ", "\[Tau]A", " ", "rW"}]}], ")"}], 
        RowBox[{"SolRad", "[", "t", "]"}]}], "+", " ", 
       RowBox[{"\[Alpha]AT", "*", "\[Sigma]B", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p", " ", "\[Epsilon]G", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"TG", "[", "t", "]"}], ")"}], "4"]}], "+", 
          RowBox[{"q", " ", "\[Epsilon]W", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"TW", "[", "t", "]"}], " ", ")"}], "4"]}]}], ")"}]}], 
       "-", " ", 
       RowBox[{"\[Sigma]B", " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]Au", "+", "\[Epsilon]Ad"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"TA", "[", "t", "]"}], " ", ")"}], "4"]}], " ", "+", 
       RowBox[{"p", " ", "hAG", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"TG", "[", "t", "]"}], "-", 
          RowBox[{"TA", "[", "t", "]"}]}], ")"}]}], "+", 
       RowBox[{"q", " ", "hAW", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"TW", "[", "t", "]"}], "-", 
          RowBox[{"TA", "[", "t", "]"}]}], ")"}]}], " ", "-", 
       RowBox[{"\[CapitalLambda]", " ", "*", "  ", 
        RowBox[{"Min", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Mu]", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["E", 
               RowBox[{
                RowBox[{"0.0666", " ", 
                 RowBox[{"TA", "[", "t", "]"}]}], "-", "23.96"}]], "-", 
              RowBox[{"U", "[", "t", "]"}]}], ")"}]}], "-", " ", 
           RowBox[{"\[Nu]", " ", 
            RowBox[{"U", "[", "t", "]"}]}]}], ",", "0"}], "]"}]}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Cl", " ", 
       RowBox[{
        RowBox[{"TG", "'"}], "[", "t", "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Tau]A", "  ", "\[Alpha]G", " ", 
        RowBox[{"SolRad", "[", "t", "]"}]}], "+", 
       RowBox[{"\[Sigma]B", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Epsilon]Ad", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"TA", "[", "t", "]"}], " ", ")"}], "4"]}], "-", 
          RowBox[{"\[Epsilon]G", "  ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"TG", "[", "t", "]"}], " ", ")"}], "4"]}]}], ")"}]}], 
       " ", "-", " ", 
       RowBox[{"hAG", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"TG", "[", "t", "]"}], "-", 
          RowBox[{"TA", "[", "t", "]"}]}], ")"}]}], "+", "qG", "-", " ", 
       RowBox[{"\[CapitalLambda]", " ", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Mu]", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["E", 
               RowBox[{
                RowBox[{"0.0666", " ", 
                 RowBox[{"TA", "[", "t", "]"}]}], "-", "23.96"}]], "-", 
              RowBox[{"U", "[", "t", "]"}]}], ")"}]}], "-", " ", 
           RowBox[{"\[Nu]", " ", 
            RowBox[{"U", "[", "t", "]"}]}]}], ",", "0"}], "]"}]}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Cw", " ", 
       RowBox[{
        RowBox[{"TW", "'"}], "[", "t", "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Tau]A", "  ", "\[Alpha]W", "  ", 
        RowBox[{"SolRad", "[", "t", "]"}]}], "+", " ", 
       RowBox[{"\[Sigma]B", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Epsilon]Ad", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"TA", "[", "t", "]"}], " ", ")"}], "4"]}], " ", "-", " ", 
          RowBox[{"\[Epsilon]W", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"TW", "[", "t", "]"}], " ", ")"}], "4"]}]}], ")"}]}], 
       "-", 
       RowBox[{"hAW", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"TW", "[", "t", "]"}], "-", 
          RowBox[{"TA", "[", "t", "]"}]}], ")"}]}], "  ", "+", " ", "qW", "-",
        "  ", 
       RowBox[{"\[CapitalLambda]", " ", "*", " ", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Mu]", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["E", 
               RowBox[{
                RowBox[{"0.0666", " ", 
                 RowBox[{"TA", "[", "t", "]"}]}], "-", "23.96"}]], "-", 
              RowBox[{"U", "[", "t", "]"}]}], ")"}]}], "-", " ", 
           RowBox[{"\[Nu]", " ", 
            RowBox[{"U", "[", "t", "]"}]}]}], ",", "0"}], "]"}]}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"U", "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Mu]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["E", 
           RowBox[{
            RowBox[{"0.0666", 
             RowBox[{"TA", "[", "t", "]"}]}], "-", "23.96"}]], "-", 
          RowBox[{"U", "[", "t", "]"}]}], ")"}]}], "-", " ", 
       RowBox[{"\[Nu]", " ", 
        RowBox[{"U", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CurlyTheta]", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Pi]", " "}], 
        RowBox[{"Year", " ", 
         SuperscriptBox[
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", 
            SuperscriptBox["\[Epsilon]", "2"]}], "]"}], "3"]}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Epsilon]", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[CurlyTheta]", "[", "t", "]"}], "]"}]}]}], ")"}], 
        "2"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solution", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"system", ",", 
       RowBox[{
        RowBox[{"TG", "[", "0", "]"}], "\[Equal]", " ", "TG0"}], ",", 
       RowBox[{
        RowBox[{"TW", "[", "0", "]"}], "\[Equal]", " ", "TW0"}], ",", 
       RowBox[{
        RowBox[{"TA", "[", "0", "]"}], "\[Equal]", " ", "TA0"}], ",", 
       RowBox[{
        RowBox[{"U", "[", "0", "]"}], "\[Equal]", "U0"}], ",", 
       RowBox[{
        RowBox[{"\[CurlyTheta]", "[", "0", "]"}], "\[Equal]", 
        "\[CurlyTheta]0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"TG", ",", "TW", ",", "TA", ",", "U", ",", "\[CurlyTheta]"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"1.01", " ", "Year"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"TA0", "-", 
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
         RowBox[{"365", "*", "Day"}], "]"}]}], "]"}], ">", 
      SuperscriptBox["10", 
       RowBox[{"-", "1"}]]}], "||", " ", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"TG0", "-", 
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"TG", "/.", "solution"}], "]"}], "[", 
         RowBox[{"365", "*", "Day"}], "]"}]}], "]"}], ">", 
      SuperscriptBox["10", 
       RowBox[{"-", "1"}]]}], "  ", "||", " ", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"TW0", "-", 
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"TW", "/.", "solution"}], "]"}], "[", 
         RowBox[{"365", "*", "Day"}], "]"}]}], "]"}], ">", 
      SuperscriptBox["10", 
       RowBox[{"-", "1"}]]}], "  ", "||", " ", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"U0", "-", 
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"U", "/.", "solution"}], "]"}], "[", 
         RowBox[{"365", "*", "Day"}], "]"}]}], "]"}], ">", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], " ", ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"TA1", "=", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
       RowBox[{"365", "*", "Day"}], "]"}]}], " ", ";", 
     RowBox[{"TG1", "=", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"TG", "/.", "solution"}], "]"}], "[", 
       RowBox[{"365", "*", "Day"}], "]"}]}], " ", ";", 
     RowBox[{"TW1", "=", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"TW", "/.", "solution"}], "]"}], "[", 
       RowBox[{"365", "*", "Day"}], "]"}]}], " ", ";", 
     RowBox[{"U1", "=", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"U", "/.", "solution"}], "]"}], "[", 
       RowBox[{"365", "*", "Day"}], "]"}]}], ";", "\[IndentingNewLine]", " ", 
     RowBox[{"solution", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"system", ",", 
          RowBox[{
           RowBox[{"TG", "[", "0", "]"}], "\[Equal]", " ", "TG1"}], ",", 
          RowBox[{
           RowBox[{"TW", "[", "0", "]"}], "\[Equal]", " ", "TW1"}], ",", 
          RowBox[{
           RowBox[{"TA", "[", "0", "]"}], "\[Equal]", " ", "TA1"}], ",", 
          RowBox[{
           RowBox[{"U", "[", "0", "]"}], "\[Equal]", "U1"}], ",", 
          RowBox[{
           RowBox[{"\[CurlyTheta]", "[", "0", "]"}], "\[Equal]", 
           "\[CurlyTheta]0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"TG", ",", "TW", ",", "TA", ",", "U", ",", "\[CurlyTheta]"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"1.01", " ", "Year"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"TA0", "=", "TA1"}], ";", 
     RowBox[{"TG0", "=", "TG1"}], ";", 
     RowBox[{"TW0", "=", "TW1"}], ";", 
     RowBox[{"U0", "=", "U1"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8287955260122843`*^9, 3.8287955267076387`*^9}, {
   3.829116810499198*^9, 3.829116811057446*^9}, 3.829116862254766*^9, 
   3.829117105796824*^9, {3.829117231665955*^9, 3.829117372495171*^9}, {
   3.829131519824073*^9, 3.829131520282411*^9}, {3.829133198792317*^9, 
   3.8291332177247972`*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"69d5216e-2e77-464f-86e5-1cdc5a63b930"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization", "Section",
 CellChangeTimes->{{3.828531800469637*^9, 3.8285318078375177`*^9}, {
  3.8287947912889147`*^9, 3.828794794336699*^9}, {3.829117656510005*^9, 
  3.829117658807857*^9}},ExpressionUUID->"59f063e9-a196-42ff-a4f4-\
3ded3a34320c"],

Cell[CellGroupData[{

Cell["Yearly temperature and humidity", "Subsection",
 CellChangeTimes->{{3.8291295802981863`*^9, 3.82912958552598*^9}, {
  3.829129617989101*^9, 
  3.829129629337295*^9}},ExpressionUUID->"39db1433-a63d-421d-a995-\
f0f0b9696d1a"],

Cell["\<\
The following lines plot the real averaged temperature and relative humidity \
together with the ones computed with the model\
\>", "Text",
 CellChangeTimes->{{3.829117663433168*^9, 3.829117718770928*^9}, {
  3.829117768594705*^9, 
  3.829117781103527*^9}},ExpressionUUID->"d8878c12-83ac-4b93-97cd-\
08482b3192da"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tottmp", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"StringJoin", "[", 
     RowBox[{"\"\<tmp_\>\"", ",", "code", ",", "\"\<.dat\>\""}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tothmd", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"StringJoin", "[", 
     RowBox[{"\"\<hmd_\>\"", ",", "code", ",", "\"\<.dat\>\""}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tmp", "=", 
   RowBox[{"Evaluate", "@", 
    RowBox[{"Interpolation", "[", 
     RowBox[{"tottmp", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hmdr", "=", 
   RowBox[{"Evaluate", "@", 
    RowBox[{"Interpolation", "[", 
     RowBox[{"tothmd", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"US", "[", "T_", "]"}], ":=", 
   SuperscriptBox["E", 
    RowBox[{
     RowBox[{"0.0666", "T"}], "-", "23.96"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hmd", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Hmdr", "[", "t", "]"}], 
   RowBox[{"US", "[", 
    RowBox[{
     RowBox[{"Tmp", "[", "t", "]"}], "+", "273.15"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"realTmp", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Tmp", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "365"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "1000"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Opacity", "[", "0.4", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"realHmdr", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Hmdr", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "365"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "1000"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solstices", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"79", ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Green"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"172", ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", 
         RowBox[{"Darker", "[", "Orange", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"266", ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Brown"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"355", ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Cyan"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
       RowBox[{"t", " ", "Day"}], "]"}], "-", "273.15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "365"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Opacity", "[", "0.8", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "5000"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "realTmp"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"solstices", ",", "None"}], "}"}]}], ",", 
   RowBox[{"GridLinesStyle", "\[Rule]", "  ", 
    RowBox[{"Thickness", "[", "0.003", "]"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Arrowheads", "[", "0.03", "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<days\>\"", ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(\
\[SmallCircle]\)]\)C\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"First", "[", 
       RowBox[{"U", "/.", "solution"}], "]"}], "[", 
      RowBox[{"t", " ", "Day"}], "]"}], 
     RowBox[{"US", "[", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
       RowBox[{"t", " ", "Day"}], "]"}], "]"}]], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "365"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", "0.6", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "3000"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "realHmdr"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"solstices", ",", "None"}], "}"}]}], ",", 
   RowBox[{"GridLinesStyle", "\[Rule]", "  ", 
    RowBox[{"Thickness", "[", "0.003", "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Arrowheads", "[", "0.03", "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", "\"\<\[InvisiblePrefixScriptBase]\>\""}], 
     "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.829117721303316*^9, 3.82911773502492*^9}, {
   3.829118138735189*^9, 3.829118143802696*^9}, {3.829118235664403*^9, 
   3.829118277538385*^9}, {3.8291187208605833`*^9, 3.829118731964344*^9}, {
   3.829118811396287*^9, 3.8291188240165663`*^9}, {3.8291188620118*^9, 
   3.829118869316678*^9}, {3.8291189150044317`*^9, 3.829118951980658*^9}, 
   3.829119044020397*^9, {3.829127177851488*^9, 3.8291272466395617`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"bc4b6ad4-2d10-4449-9dd3-181d2aeee6a9"]
}, Closed]],

Cell[CellGroupData[{

Cell["Daily temperature and humidity", "Subsection",
 CellChangeTimes->{{3.8291295802981863`*^9, 3.82912958552598*^9}, {
  3.829129617989101*^9, 
  3.829129637370953*^9}},ExpressionUUID->"cf9c78f6-ae37-48aa-a4d5-\
4e3cbac511a1"],

Cell["\<\
The following lines, once given an integer from 0 to 365, plot the real \
averaged temperature and relative humidity together with the ones computed \
with the model in a period of three days starting form the chosen day. The \
spring equinox takes place at day 79,  the summer solstice takes place at day \
172, the autumn equinox takes place at day 266,  the winter solstice takes \
place at day 355. \
\>", "Text",
 CellChangeTimes->{{3.829117663433168*^9, 3.829117881865398*^9}, {
  3.829118345123663*^9, 3.829118408209197*^9}, {3.829118466304089*^9, 
  3.8291185127408867`*^9}, {3.829118543555649*^9, 
  3.829118614320333*^9}},ExpressionUUID->"133bb36a-1b57-4321-95db-\
47fa3c8f57df"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"day", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"col", "[", "i_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"Dashed", ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"EvenQ", "[", "i", "]"}], ",", "Blue", ",", 
       RowBox[{"Darker", "[", "Orange", "]"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threedaysTmp", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Tmp", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "day", ",", 
       RowBox[{"day", "+", "3"}]}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "1000"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.003", "]"}], ",", "Black"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threedaysHmdr", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Hmdr", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "day", ",", 
       RowBox[{"day", "+", "3"}]}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "1000"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.003", "]"}], ",", "Black"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threedaysTmpsim", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
       RowBox[{"t", " ", "Day"}], "]"}], "-", "273.15"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "day", ",", 
       RowBox[{"day", "+", "3"}]}], "}"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox["i", "2"], "-", 
             FractionBox["long", "360"]}], ",", 
            RowBox[{"col", "[", "i", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", 
            AdjustmentBox[",",
             
             BoxMargins->{{0.07122506948339123, -0.07122506948339123}, {0., 
              0.}}], "365"}], "}"}]}], "]"}], ",", "None"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.004", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "3000"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "95"}], ",", "95"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threedaysHmdrsim", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"U", "/.", "solution"}], "]"}], "[", 
       RowBox[{"t", " ", "Day"}], "]"}], 
      RowBox[{"US", "[", 
       RowBox[{
        RowBox[{"First", "[", 
         RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
        RowBox[{"t", " ", "Day"}], "]"}], "]"}]], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "day", ",", 
       RowBox[{"day", "+", "3"}]}], "}"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox["i", "2"], "-", 
             FractionBox["long", "360"]}], ",", 
            RowBox[{"col", "[", "i", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", 
            AdjustmentBox[",",
             
             BoxMargins->{{0.07122506948339123, -0.07122506948339123}, {0., 
              0.}}], 
            RowBox[{"2", "*", "365"}]}], "}"}]}], "]"}], ",", "None"}], 
       "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.004", "]"}], ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "3000"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{"Row", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"threedaysTmpsim", ",", "threedaysTmp"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "35"}], "}"}]}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Arrowheads", "[", "0.04", "]"}]}], ",", " ", 
       RowBox[{"GridLinesStyle", " ", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", " ", 
       RowBox[{"Ticks", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"i", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "400"}], "}"}]}], "]"}], ",", 
          "Automatic"}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<days\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(\
\[SmallCircle]\)]\)C\>\""}], "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", " ", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"threedaysHmdrsim", ",", "threedaysHmdr"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Arrowheads", "[", "0.04", "]"}]}], ",", 
       RowBox[{"GridLinesStyle", " ", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", " ", 
       RowBox[{"Ticks", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"i", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "400"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.2", ",", "0.4", ",", "0.6", ",", "0.8", ",", "1"}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<days\>\"", ",", "\"\<\[InvisiblePrefixScriptBase]\>\""}], 
         "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", " ", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "}"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.8291178846379423`*^9, 3.829117884909336*^9}, {
   3.829118297285221*^9, 3.829118340148685*^9}, {3.829118422623765*^9, 
   3.829118430949367*^9}, {3.829118634911601*^9, 3.829118706822137*^9}, {
   3.8291187469996443`*^9, 3.829118747378414*^9}, 3.829118787495162*^9, {
   3.829118852815892*^9, 3.829118856156808*^9}, 3.829118913445717*^9, {
   3.8291189724277067`*^9, 3.82911905734995*^9}, {3.829127267122375*^9, 
   3.82912738838519*^9}, {3.8291315489978943`*^9, 3.829131549124919*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"623bc486-3771-4e67-a355-34e568a094f9"],

Cell["\<\
We create a spline of the average temperatures for every day of the year. We \
triplicate the list of temperatures and choose the central year to avoid \
aberrations at the beginning or at the end of the graph due to the spline \
algorithm.\
\>", "Text",
 CellChangeTimes->{{3.829128590435216*^9, 
  3.829128678236292*^9}},ExpressionUUID->"6cf4f61c-4521-494e-bbbe-\
2f6d4c390b87"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analysis", "Section",
 CellChangeTimes->{{3.829132685709486*^9, 
  3.829132688596569*^9}},ExpressionUUID->"791c30a5-e39d-4d8f-984e-\
e0172bf670a0"],

Cell[CellGroupData[{

Cell["L1 distance", "Subsection",
 CellChangeTimes->{{3.8291295802981863`*^9, 3.829129601555081*^9}, {
  3.8291327180888023`*^9, 
  3.8291327220082083`*^9}},ExpressionUUID->"b03eb0b3-cea5-4b6d-88ca-\
31dd4ad80c92"],

Cell["\<\
To determine the accuracy of the simulated temperature, we define a function \
that computes a discretized L1-distance. On average the real temperature and \
the simulated one differ by the amount indicated by the output\
\>", "Text",
 CellChangeTimes->{{3.829132723000265*^9, 3.829132793749628*^9}, {
  3.829132889609833*^9, 3.829132939391569*^9}, {3.829133254570026*^9, 
  3.8291333227211123`*^9}},ExpressionUUID->"12aa67c5-8fe9-4d8b-90a8-\
405214a078a6"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"Length", "[", "tottmp", "]"}]], 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"tottmp", "[", 
        RowBox[{"[", 
         RowBox[{"ind", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"First", "[", 
           RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
          RowBox[{"Day", " ", 
           RowBox[{"tottmp", "[", 
            RowBox[{"[", 
             RowBox[{"ind", ",", "1"}], "]"}], "]"}]}], "]"}], "-", 
         "273.15"}], ")"}]}], ")"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ind", ",", "1", ",", 
      RowBox[{"Length", "[", "tottmp", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.829132906627512*^9, {3.8291331422088213`*^9, 3.829133147744424*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"ec8ac3e3-8967-4b50-9a26-863403dc63ed"],

Cell["\<\
This line determines the accuracy of the simulated relative humidity. On \
average the real relative humidity and the simulated one differ by the amount \
indicated by the output\
\>", "Text",
 CellChangeTimes->{{3.829132723000265*^9, 3.829132793749628*^9}, {
  3.829132889609833*^9, 3.82913293482694*^9}, {3.829132996226489*^9, 
  3.829132997284074*^9}, {3.829133296245224*^9, 
  3.82913331937024*^9}},ExpressionUUID->"1f1bf2c7-cdbe-4686-822b-\
433cf5c78ef7"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"Length", "[", "tothmd", "]"}]], 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"tothmd", "[", 
        RowBox[{"[", 
         RowBox[{"ind", ",", "2"}], "]"}], "]"}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"U", "/.", "solution"}], "]"}], "[", 
         RowBox[{"Day", " ", 
          RowBox[{"tothmd", "[", 
           RowBox[{"[", 
            RowBox[{"ind", ",", "1"}], "]"}], "]"}]}], "]"}], 
        RowBox[{"US", "[", 
         RowBox[{
          RowBox[{"First", "[", 
           RowBox[{"TA", "/.", "solution"}], "]"}], "[", 
          RowBox[{"Day", " ", 
           RowBox[{"tothmd", "[", 
            RowBox[{"[", 
             RowBox[{"ind", ",", "1"}], "]"}], "]"}]}], "]"}], "]"}]]}], 
      ")"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ind", ",", "1", ",", 
      RowBox[{"Length", "[", "tothmd", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.829132848433069*^9, 3.8291329080866613`*^9}, {
  3.829132963254819*^9, 3.8291329730884123`*^9}},
 CellLabel->
  "In[154]:=",ExpressionUUID->"b8207836-82b2-4ce1-a3f4-76b716d07f02"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lag of season", "Subsection",
 CellChangeTimes->{{3.8291295802981863`*^9, 
  3.829129601555081*^9}},ExpressionUUID->"84d72398-259d-478a-a3bb-\
b9a75ae8d0a6"],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<Splines`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmpYmean", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"Mean", ",", 
       RowBox[{"SplitBy", "[", 
        RowBox[{
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Floor", "[", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
           "tottmp"}], "]"}], ",", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}]}], "]"}]}], "]"}], "]"}], 
    "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmpYmeanlong", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"tmpYmean", ",", "tmpYmean", ",", "tmpYmean"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmpYmeanspline", "=", 
   RowBox[{"BezierFunction", "[", "tmpYmeanlong", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8291179431836452`*^9, 3.829117943458169*^9}, {
  3.829127399983446*^9, 3.829127412125544*^9}, {3.829127448088814*^9, 
  3.829127499741715*^9}, {3.829128073092313*^9, 3.8291280798861322`*^9}, {
  3.829128118620248*^9, 3.8291281259529448`*^9}, {3.829128161596397*^9, 
  3.82912816348321*^9}, {3.829128478280532*^9, 3.829128538265545*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"cd336de9-145b-4f98-be98-f8a975d42f65"],

Cell["\<\
We do the same for the amount of daily energy. This requires the computation \
of 365 numerical integration which is long.\
\>", "Text",
 CellChangeTimes->{{3.829117663433168*^9, 3.8291179454813547`*^9}, {
  3.829127818145754*^9, 3.82912786521616*^9}, {3.8291286831085463`*^9, 
  3.829128710414729*^9}},ExpressionUUID->"4c12b6fe-8e85-49d5-8be4-\
a39f4d5c5e42"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"solenerg", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"SolRad", "[", 
          RowBox[{"t", " ", "Day"}], "]"}], "/.", "solution"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "d", ",", 
          RowBox[{"d", "+", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", "0", ",", "364"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solenerglong", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"solenerg", ",", "solenerg", ",", "solenerg"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solenergspline", "=", 
   RowBox[{"BezierFunction", "[", "solenerglong", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.82912871987914*^9, 3.829128723461712*^9}, {
  3.829132031631068*^9, 3.8291320357126217`*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"07a7ce60-b36f-41be-a308-beeccde18960"],

Cell["\<\
We hence compute the maximum of solar energy and the maximum of temperature \
during the year. The algorithm requires and initial guess that should \
possibly  be changed.\
\>", "Text",
 CellChangeTimes->{{3.8291276950989523`*^9, 3.829127729864316*^9}, {
  3.829127779249749*^9, 3.8291278117581377`*^9}, {3.82912873644452*^9, 
  3.829128745075012*^9}},ExpressionUUID->"f62bc519-2859-459d-a09c-\
895e81332dd6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"guessmaxenerg", "=", "180"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"guessmaxtmp", "=", "220"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxenerg", "=", 
   RowBox[{
    RowBox[{"FindArgMax", "[", 
     RowBox[{
      RowBox[{"solenergspline", "[", 
       FractionBox[
        RowBox[{"t", "+", "365"}], 
        RowBox[{"3", "*", " ", "365"}]], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "guessmaxenerg"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
  RowBox[{"maxtmp", "=", 
   RowBox[{
    RowBox[{"FindArgMax", "[", 
     RowBox[{
      RowBox[{"tmpYmeanspline", "[", 
       FractionBox[
        RowBox[{"t", "+", "365"}], 
        RowBox[{"3", "*", "365"}]], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "guessmaxtmp"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.829127429219963*^9, 3.829127446722035*^9}, {
  3.829127550205944*^9, 3.829127612906559*^9}, {3.829127743632991*^9, 
  3.8291277721686993`*^9}, {3.829127935583305*^9, 3.829127944788302*^9}, {
  3.829128174882374*^9, 3.829128175699197*^9}, {3.829131949572311*^9, 
  3.829131952880072*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"a8c5092e-5046-43d0-a5d5-45777eaf336d"],

Cell["We finally plot the graphs and the maxima determined above.", "Text",
 CellChangeTimes->{{3.829128754677318*^9, 
  3.829128783343644*^9}},ExpressionUUID->"9ab7dcd6-baad-40f9-8dcf-\
5a1065398c02"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TwoAxisPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f_", ",", "g_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "x1_", ",", "x2_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fgraph", ",", "ggraph", ",", "frange", ",", "grange", ",", "fticks", 
       ",", "gticks"}], "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fgraph", ",", "ggraph"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{"f", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "x1", ",", "x2"}], "}"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Darker", "[", "Orange", "]"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{"g", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "x1", ",", "x2"}], "}"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], "}"}]}], ";", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"frange", ",", "grange"}], "}"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"PlotRange", "/.", 
            RowBox[{"AbsoluteOptions", "[", 
             RowBox[{"#", ",", "PlotRange"}], "]"}]}], ")"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"fgraph", ",", "ggraph"}], "}"}]}]}], ";", 
      RowBox[{"fticks", "=", 
       RowBox[{"N", "@", 
        RowBox[{"FindDivisions", "[", 
         RowBox[{"frange", ",", "5"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gticks", "=", 
       RowBox[{"Quiet", "@", 
        RowBox[{"Transpose", "@", 
         RowBox[{"{", 
          RowBox[{"fticks", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"NumberForm", "[", 
                RowBox[{"#", ",", "3"}], "]"}], ",", "StandardForm"}], "]"}], 
             "&"}], "/@", 
            RowBox[{"Rescale", "[", 
             RowBox[{"fticks", ",", "frange", ",", "grange"}], "]"}]}]}], 
          "}"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{"fgraph", ",", 
        RowBox[{"ggraph", "/.", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"graph_", ",", "s___"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"GeometricTransformation", "[", 
             RowBox[{"graph", ",", 
              RowBox[{"RescalingTransform", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", "grange"}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", "frange"}], "}"}]}], 
               "]"}]}], "]"}], ",", "s"}], "]"}]}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Orange", "]"}], ",", "Black"}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", "Black"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"fticks", ",", "gticks"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Round", "[", 
                  RowBox[{"maxenerg", ",", "1"}], "]"}], ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Round", "[", 
                    RowBox[{"maxenerg", ",", "1"}], "]"}], ",", 
                   RowBox[{"Darker", "[", "Orange", "]"}]}], "]"}]}], "}"}], 
               ",", 
               RowBox[{"Round", "[", 
                RowBox[{"maxtmp", ",", "1"}], "]"}]}], "}"}]}], "}"}]}], 
          "}"}]}], ",", 
        RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "750"}]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"TwoAxisPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"solenergspline", "[", 
      FractionBox[
       RowBox[{"t", "+", "365"}], 
       RowBox[{"3", "*", "365"}]], "]"}], ",", 
     RowBox[{"tmpYmeanspline", "[", 
      FractionBox[
       RowBox[{"t", "+", "365"}], 
       RowBox[{"3", "*", "365"}]], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "365"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<days\>\"", ",", 
     "\"\<\!\(\*FractionBox[\(KWh\), SuperscriptBox[\(m\), \(2\)]]\)\>\"", 
     ",", "\"\<\>\"", ",", 
     "\"\<\!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(\
\[SmallCircle]\)]\)C\>\""}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.829127521524884*^9, {3.829127640436811*^9, 3.8291276810863743`*^9}, {
   3.829127880119425*^9, 3.8291279036179457`*^9}, {3.829127962992866*^9, 
   3.829127976318542*^9}, {3.829128182920982*^9, 3.829128183681835*^9}, {
   3.829128214893468*^9, 3.829128220774577*^9}, {3.829128291090638*^9, 
   3.829128292279613*^9}, {3.829128413217593*^9, 3.8291284284087887`*^9}, {
   3.829128545888349*^9, 3.829128561496275*^9}, {3.829129322564849*^9, 
   3.829129343192821*^9}},
 CellLabel->
  "In[122]:=",ExpressionUUID->"bd4d43ab-28a2-4560-9b34-69496cd7465d"],

Cell["We do the same with the simulated temperatures", "Text",
 CellChangeTimes->{{3.8291288288083353`*^9, 
  3.829128841312166*^9}},ExpressionUUID->"3f78546d-76ed-493e-93c1-\
793b31506383"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmpYmeansim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "Day"], 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"First", "[", 
           RowBox[{"TA", "/.", "solution"}], "]"}], "[", "t", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"day", " ", "Day"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"day", "+", "1"}], ")"}], "Day"}]}], "}"}]}], "]"}]}], 
      "-", "273.15"}], ",", 
     RowBox[{"{", 
      RowBox[{"day", ",", "0", ",", "364"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmpYmeansimlong", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"tmpYmeansim", ",", "tmpYmeansim", ",", "tmpYmeansim"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmpYmeansimspline", "=", 
   RowBox[{"BezierFunction", "[", "tmpYmeansimlong", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8291288443417673`*^9, 3.829128916599456*^9}, {
   3.829128951762393*^9, 3.829128956208446*^9}, 3.8291290195085087`*^9},
 CellLabel->
  "In[124]:=",ExpressionUUID->"95680cf9-0e72-4858-8be3-b69417dc4072"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxtmpsim", "=", 
   RowBox[{
    RowBox[{"FindArgMax", "[", 
     RowBox[{
      RowBox[{"tmpYmeansimspline", "[", 
       FractionBox[
        RowBox[{"t", "+", "365"}], 
        RowBox[{"3", "*", "365"}]], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "220"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"figlagb", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tmpYmeanspline", "[", 
       FractionBox[
        RowBox[{"t", "+", "365"}], 
        RowBox[{"3", "*", "365"}]], "]"}], ",", 
      RowBox[{"tmpYmeansimspline", "[", 
       FractionBox[
        RowBox[{"t", "+", "365"}], 
        RowBox[{"3", "*", "365"}]], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "365"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Red"}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Black", ",", "Black"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Black"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<days\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(\
\[SmallCircle]\)]\)C\>\""}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"None", ",", "All"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"50", " ", "i"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "8"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Round", "[", 
             RowBox[{"maxtmpsim", ",", "1"}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"maxtmpsim", ",", "1"}], "]"}], ",", "Red"}], "]"}]}], 
           "}"}], "}"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.829128935836331*^9, 3.829128999804288*^9}, {
  3.829129250138707*^9, 3.829129307741458*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"45c5872b-5bb0-410b-9640-39a417dd61f2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lag of noon", "Subsection",
 CellChangeTimes->{{3.8291295802981863`*^9, 
  3.829129605666184*^9}},ExpressionUUID->"ba3df604-811b-46e6-8b00-\
8be32128a348"],

Cell["\<\
The following line computes the average time of the day in which the \
radiation from the sun is strongest. The evaluation of these cells requires a \
long time.\
\>", "Text",
 CellChangeTimes->{{3.829117947019753*^9, 3.829117970613394*^9}, {
  3.829129652754489*^9, 3.829129684360805*^9}, {3.8291312570903177`*^9, 
  3.829131298429452*^9}},ExpressionUUID->"a87f51d9-6075-4e2a-abc3-\
92c7033168fb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MaxSolRadDay", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      FractionBox["1", "Day"], 
      RowBox[{"ArgMax", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"SolRad", "[", "t", "]"}], "/.", 
           RowBox[{"solution", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", 
          RowBox[{"t", ">", " ", 
           RowBox[{"Day", "*", "date"}]}], ",", 
          RowBox[{"t", "<", " ", 
           RowBox[{"Day", "*", 
            RowBox[{"(", 
             RowBox[{"date", "+", "1"}], ")"}]}]}]}], "}"}], ",", "t"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"date", ",", "0", ",", "364", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MaxSolRadDayMOD", " ", "=", " ", 
  RowBox[{
   RowBox[{"Mean", "[", 
    RowBox[{"Mod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"24", "*", 
        RowBox[{"(", 
         RowBox[{"MaxSolRadDay", "-", 
          RowBox[{"MaxSolRadDay", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "+", "12"}], ",", 
      "24"}], "]"}], "]"}], "-", "12", "+", 
   RowBox[{"24", 
    RowBox[{"MaxSolRadDay", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.829117972047282*^9, 3.829117973278454*^9}, {
   3.829129057683213*^9, 3.829129067284772*^9}, {3.8291293797812443`*^9, 
   3.829129412286442*^9}, {3.82912994421894*^9, 3.8291299949979753`*^9}, 
   3.829131194651286*^9},
 CellLabel->
  "In[129]:=",ExpressionUUID->"54a59b9d-a739-43e1-9e3e-7726a22f6792"],

Cell["\<\
The following line computes the average time of the day in which the real \
temperature is the highest.\
\>", "Text",
 CellChangeTimes->{{3.829117947019753*^9, 3.829117970613394*^9}, {
  3.829129652754489*^9, 3.829129684360805*^9}, {3.8291312570903177`*^9, 
  3.829131332191895*^9}},ExpressionUUID->"67f783c7-185e-48a2-ae50-\
972445e6b58f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"splitted", "=", 
   RowBox[{"SplitBy", "[", 
    RowBox[{"tottmp", ",", 
     RowBox[{
      RowBox[{"Floor", "[", 
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxDayReal", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"splitted", "[", 
       RowBox[{"[", 
        RowBox[{"iter", "+", "1"}], "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"splitted", "[", 
             RowBox[{"[", 
              RowBox[{"iter", "+", "1"}], "]"}], "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"Max", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"splitted", "[", 
              RowBox[{"[", 
               RowBox[{"iter", "+", "1"}], "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"iter", ",", "0", ",", "364"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxTempRealDay", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", "maxDayReal", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"maxTempRealDayMOD", " ", "=", " ", 
  RowBox[{
   RowBox[{"Mean", "[", 
    RowBox[{"Mod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"24", "*", 
        RowBox[{"(", 
         RowBox[{"maxTempRealDay", "-", 
          RowBox[{"maxTempRealDay", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "+", "12"}], ",", 
      "24"}], "]"}], "]"}], "-", "12", "+", 
   RowBox[{"24", 
    RowBox[{"maxTempRealDay", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.8281851418368454`*^9, 3.82818514405346*^9}, {
  3.829129074863904*^9, 3.829129078890379*^9}, {3.829129991994779*^9, 
  3.829129992534594*^9}, {3.8291312100073957`*^9, 3.8291312159339743`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"0988fff5-73b1-495c-852d-3e141d798ccd"],

Cell["\<\
The following line computes the average time of the day in which the \
simulated temperature is highest. The evaluation of these cells requires a \
long time.\
\>", "Text",
 CellChangeTimes->{{3.829117947019753*^9, 3.829117970613394*^9}, {
  3.829129652754489*^9, 3.829129684360805*^9}, {3.8291312570903177`*^9, 
  3.829131298429452*^9}, {3.829131345564337*^9, 
  3.8291313603411913`*^9}},ExpressionUUID->"aba9e676-f059-43cb-b8e6-\
bb1bd3a97fef"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MaxTempSimDay", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      FractionBox["1", "Day"], 
      RowBox[{"ArgMax", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"First", "[", 
            RowBox[{"TA", "/.", "solution"}], "]"}], "[", "t", "]"}], ",", 
          RowBox[{"t", ">", " ", 
           RowBox[{"Day", "*", "date"}]}], ",", 
          RowBox[{"t", "<", " ", 
           RowBox[{"Day", "*", 
            RowBox[{"(", 
             RowBox[{"date", "+", "1"}], ")"}]}]}]}], "}"}], ",", "t"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"date", ",", "0", ",", "364", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MaxTempSimDayMOD", " ", "=", "  ", 
  RowBox[{
   RowBox[{"Mean", "[", 
    RowBox[{"Mod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"24", "*", 
        RowBox[{"(", 
         RowBox[{"MaxTempSimDay", "-", 
          RowBox[{"MaxTempSimDay", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "+", "12"}], ",", 
      "24"}], "]"}], "]"}], "-", "12", "+", 
   RowBox[{"24", 
    RowBox[{"MaxTempSimDay", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{
  3.827990509026836*^9, 3.827990826834777*^9, {3.8279911236391363`*^9, 
   3.827991124543594*^9}, {3.827992672053564*^9, 3.827992674094091*^9}, 
   3.827994669655608*^9, {3.8281835630339565`*^9, 3.828183577639669*^9}, {
   3.8281836581867313`*^9, 3.828183659026697*^9}, 3.8281851583755817`*^9, {
   3.828481864141817*^9, 3.8284818713619504`*^9}, 3.828532563634143*^9, 
   3.8291290819700727`*^9, {3.829129421027443*^9, 3.82912942822539*^9}, {
   3.829129918196885*^9, 3.829129918420464*^9}, {3.829131223680563*^9, 
   3.829131229628687*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"f449c0cd-7139-44ee-a876-902822dd509d"],

Cell["The real and the simulated lag of noons are hence", "Text",
 CellChangeTimes->{{3.829131363291561*^9, 3.8291313853123503`*^9}, {
  3.829131450073412*^9, 
  3.829131466601265*^9}},ExpressionUUID->"4540aa92-afbc-4f6e-a873-\
5a6b776c6357"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TimeObject", "[", "maxTempRealDayMOD", "]"}], "-", 
  RowBox[{
  "TimeObject", "[", "MaxSolRadDayMOD", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TimeObject", "[", "MaxTempSimDayMOD", "]"}], "-", 
  RowBox[{"TimeObject", "[", "MaxSolRadDayMOD", "]"}]}]}], "Input",
 CellChangeTimes->{{3.8281843007519717`*^9, 3.8281843092300096`*^9}, {
  3.8281848523845167`*^9, 3.8281848615325775`*^9}, {3.8281851809104595`*^9, 
  3.828185187576647*^9}, {3.828185298705039*^9, 3.82818531204088*^9}, {
  3.8291313933903008`*^9, 3.8291314398213673`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"32e8bc5e-62aa-4116-85d2-0c1c446acdb8"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1623, 997},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"b6a8f37a-5254-42f8-8d54-ed5557edaf93"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 226, 5, 98, "Title",ExpressionUUID->"f3a83daf-1766-4437-b239-f2b40d90fcfa"],
Cell[CellGroupData[{
Cell[831, 31, 172, 3, 67, "Section",ExpressionUUID->"d5a07e46-faaa-4a41-b47d-5e6dd09e7319"],
Cell[1006, 36, 472, 11, 35, "Text",ExpressionUUID->"555795d1-e7c8-4b73-85dd-d720dfa53314"],
Cell[1481, 49, 835, 13, 58, "Text",ExpressionUUID->"bddd78d3-2ddd-48e6-81be-2739a5150eff"],
Cell[2319, 64, 809, 20, 35, "Text",ExpressionUUID->"218fe883-0878-4eaa-b185-b7687c7485b0"],
Cell[3131, 86, 282, 7, 35, "Text",ExpressionUUID->"6b299363-7657-4498-981a-76658d6a9114"],
Cell[3416, 95, 268, 5, 30, "Input",ExpressionUUID->"d61f5abb-0f2c-4ea5-a852-f2b698cc294a"],
Cell[3687, 102, 1289, 31, 58, "Text",ExpressionUUID->"f4950ab2-21ec-49da-a226-10e1118fff20"],
Cell[4979, 135, 7088, 174, 379, "Input",ExpressionUUID->"69b92b07-b9d2-496a-b15c-89b48245b077"],
Cell[12070, 311, 1090, 19, 196, "Text",ExpressionUUID->"74595441-440f-4812-a02e-d93d2bb0ceea"],
Cell[13163, 332, 331, 8, 30, "Input",ExpressionUUID->"b4c52e71-ef85-4236-b98d-ff299b7a5aa3"],
Cell[13497, 342, 479, 10, 30, "Input",ExpressionUUID->"0daae329-afe0-4c8d-9329-6d9fa2cd2b87"],
Cell[13979, 354, 527, 10, 30, "Input",ExpressionUUID->"3b16e1de-fd87-4c6e-92cb-e82b71985d1b"],
Cell[14509, 366, 435, 9, 30, "Input",ExpressionUUID->"bbf33c36-c223-4529-99a5-93318ff9912d"],
Cell[14947, 377, 389, 9, 30, "Input",ExpressionUUID->"7c6c111b-29d3-4c12-b6c4-7c95999b6fed"],
Cell[15339, 388, 358, 8, 30, "Input",ExpressionUUID->"d14c1600-3055-4798-8a91-b59efab230c7"]
}, Closed]],
Cell[CellGroupData[{
Cell[15734, 401, 208, 4, 53, "Section",ExpressionUUID->"6e87f9a4-ee61-4928-bbc1-8ec5533d17a0"],
Cell[15945, 407, 541, 10, 35, "Text",ExpressionUUID->"8179347b-0e42-416b-9f0c-aa2b7742c907"],
Cell[16489, 419, 354, 7, 30, "Input",ExpressionUUID->"6cbc63f3-18b4-429c-adf4-20eb1107f326"],
Cell[16846, 428, 377, 8, 35, "Text",ExpressionUUID->"9e0960fa-3ebd-4186-897f-1fbd7adc2613"],
Cell[17226, 438, 2878, 78, 324, "Input",ExpressionUUID->"029ed9f9-848b-45e6-a6f6-dce24c618af1"],
Cell[20107, 518, 403, 9, 35, "Text",ExpressionUUID->"e8341638-958a-49c5-93b2-91872d06599d"],
Cell[20513, 529, 871, 24, 73, "Input",ExpressionUUID->"3c8f919f-bae9-4b28-acd2-7981f3414917"],
Cell[21387, 555, 478, 10, 35, "Text",ExpressionUUID->"4360af3d-13b0-4cc8-b325-bff20ef0528d"],
Cell[21868, 567, 4093, 118, 264, "Input",ExpressionUUID->"582f03cb-8117-431e-927b-9d1e7a64c1f4"],
Cell[25964, 687, 510, 11, 35, "Text",ExpressionUUID->"7326a8c9-c062-46ce-b9ee-f41c79ea109a"],
Cell[26477, 700, 1077, 31, 94, "Input",ExpressionUUID->"17231944-f58a-404a-ac45-e40284c55f26"],
Cell[27557, 733, 453, 10, 35, "Text",ExpressionUUID->"004c3704-eede-4bbe-a823-a2a481a36847"],
Cell[28013, 745, 1903, 51, 178, "Input",ExpressionUUID->"47457cfb-deff-49dc-8a00-a652bdec992a"],
Cell[29919, 798, 282, 9, 35, "Text",ExpressionUUID->"efe67ee0-4c12-41ab-a08b-c6ad5b7a56d7"],
Cell[30204, 809, 929, 24, 52, "Input",ExpressionUUID->"0cf31df3-6278-433b-9632-4bc5f9035ae7"],
Cell[31136, 835, 355, 9, 35, "Text",ExpressionUUID->"eb85cb95-71b8-465f-93b4-df997b81e592"],
Cell[31494, 846, 3178, 86, 388, "Input",ExpressionUUID->"45af90a2-0202-4631-9d65-570b4b4f6e82"],
Cell[34675, 934, 389, 10, 35, "Text",ExpressionUUID->"9f9ed3b5-d2d8-4acb-a4e5-5df7a8363000"],
Cell[35067, 946, 581, 16, 52, "Input",ExpressionUUID->"a97f1aeb-4cc2-4829-a242-4b0c2f7e6f2b"],
Cell[35651, 964, 803, 20, 64, "Text",ExpressionUUID->"87340c08-b044-433d-8a16-930b9f1bc4a8"],
Cell[36457, 986, 3446, 99, 118, "Input",ExpressionUUID->"60aed318-a606-4326-bf45-18de0c0e65cf"],
Cell[39906, 1087, 559, 10, 58, "Text",ExpressionUUID->"225a226a-b0bd-403f-8d21-6c55d773c46e"],
Cell[40468, 1099, 12257, 340, 475, "Input",ExpressionUUID->"69d5216e-2e77-464f-86e5-1cdc5a63b930"]
}, Closed]],
Cell[CellGroupData[{
Cell[52762, 1444, 257, 4, 53, "Section",ExpressionUUID->"59f063e9-a196-42ff-a4f4-3ded3a34320c"],
Cell[CellGroupData[{
Cell[53044, 1452, 229, 4, 54, "Subsection",ExpressionUUID->"39db1433-a63d-421d-a995-f0f0b9696d1a"],
Cell[53276, 1458, 324, 7, 35, "Text",ExpressionUUID->"d8878c12-83ac-4b93-97cd-08482b3192da"],
Cell[53603, 1467, 6444, 178, 329, "Input",ExpressionUUID->"bc4b6ad4-2d10-4449-9dd3-181d2aeee6a9"]
}, Closed]],
Cell[CellGroupData[{
Cell[60084, 1650, 228, 4, 38, "Subsection",ExpressionUUID->"cf9c78f6-ae37-48aa-a4d5-4e3cbac511a1"],
Cell[60315, 1656, 699, 12, 58, "Text",ExpressionUUID->"133bb36a-1b57-4321-95db-47fa3c8f57df"],
Cell[61017, 1670, 7262, 195, 345, "Input",ExpressionUUID->"623bc486-3771-4e67-a355-34e568a094f9"],
Cell[68282, 1867, 390, 8, 35, "Text",ExpressionUUID->"6cf4f61c-4521-494e-bbbe-2f6d4c390b87"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68721, 1881, 153, 3, 67, "Section",ExpressionUUID->"791c30a5-e39d-4d8f-984e-e0172bf670a0"],
Cell[CellGroupData[{
Cell[68899, 1888, 214, 4, 54, "Subsection",ExpressionUUID->"b03eb0b3-cea5-4b6d-88ca-31dd4ad80c92"],
Cell[69116, 1894, 467, 8, 35, "Text",ExpressionUUID->"12aa67c5-8fe9-4d8b-90a8-405214a078a6"],
Cell[69586, 1904, 955, 28, 50, "Input",ExpressionUUID->"ec8ac3e3-8967-4b50-9a26-863403dc63ed"],
Cell[70544, 1934, 470, 9, 35, "Text",ExpressionUUID->"1f1bf2c7-cdbe-4686-822b-433cf5c78ef7"],
Cell[71017, 1945, 1229, 35, 51, "Input",ExpressionUUID->"b8207836-82b2-4ce1-a3f4-76b716d07f02"]
}, Closed]],
Cell[CellGroupData[{
Cell[72283, 1985, 163, 3, 38, "Subsection",ExpressionUUID->"84d72398-259d-478a-a3bb-b9a75ae8d0a6"],
Cell[72449, 1990, 1590, 39, 94, "Input",ExpressionUUID->"cd336de9-145b-4f98-be98-f8a975d42f65"],
Cell[74042, 2031, 370, 7, 35, "Text",ExpressionUUID->"4c12b6fe-8e85-49d5-8be4-a39f4d5c5e42"],
Cell[74415, 2040, 1023, 28, 73, "Input",ExpressionUUID->"07a7ce60-b36f-41be-a308-beeccde18960"],
Cell[75441, 2070, 419, 8, 35, "Text",ExpressionUUID->"f62bc519-2859-459d-a09c-895e81332dd6"],
Cell[75863, 2080, 1315, 34, 130, "Input",ExpressionUUID->"a8c5092e-5046-43d0-a5d5-45777eaf336d"],
Cell[77181, 2116, 201, 3, 35, "Text",ExpressionUUID->"9ab7dcd6-baad-40f9-8dcf-5a1065398c02"],
Cell[77385, 2121, 6227, 160, 259, "Input",ExpressionUUID->"bd4d43ab-28a2-4560-9b34-69496cd7465d"],
Cell[83615, 2283, 190, 3, 35, "Text",ExpressionUUID->"3f78546d-76ed-493e-93c1-793b31506383"],
Cell[83808, 2288, 1234, 34, 94, "Input",ExpressionUUID->"95680cf9-0e72-4858-8be3-b69417dc4072"],
Cell[85045, 2324, 2705, 74, 140, "Input",ExpressionUUID->"45c5872b-5bb0-410b-9640-39a417dd61f2"]
}, Closed]],
Cell[CellGroupData[{
Cell[87787, 2403, 161, 3, 38, "Subsection",ExpressionUUID->"ba3df604-811b-46e6-8b00-8be32128a348"],
Cell[87951, 2408, 408, 8, 35, "Text",ExpressionUUID->"a87f51d9-6075-4e2a-abc3-92c7033168fb"],
Cell[88362, 2418, 1601, 45, 73, "Input",ExpressionUUID->"54a59b9d-a739-43e1-9e3e-7726a22f6792"],
Cell[89966, 2465, 350, 7, 35, "Text",ExpressionUUID->"67f783c7-185e-48a2-ae50-972445e6b58f"],
Cell[90319, 2474, 2280, 64, 94, "Input",ExpressionUUID->"0988fff5-73b1-495c-852d-3e141d798ccd"],
Cell[92602, 2540, 456, 9, 35, "Text",ExpressionUUID->"aba9e676-f059-43cb-b8e6-bb1bd3a97fef"],
Cell[93061, 2551, 1896, 49, 73, "Input",ExpressionUUID->"f449c0cd-7139-44ee-a876-902822dd509d"],
Cell[94960, 2602, 242, 4, 35, "Text",ExpressionUUID->"4540aa92-afbc-4f6e-a873-5a6b776c6357"],
Cell[95205, 2608, 666, 13, 52, "Input",ExpressionUUID->"32e8bc5e-62aa-4116-85d2-0c1c446acdb8"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

